{{
File:    RF_Robot_Console.spin
Author:  J^3
Started: 15FEB10
Updated: DDMONYR

Description:  Use propeller to interface to a PS2 controller,
              and transmit data to RF_Robot. 
}}

CON

  _xinfreq = 5_000_000
  _clkmode = xtal1 + pll2x

  R_MAX = 128
  V_MAX = 2200
  V_MIN = 800
  SQR   = 2.0

OBJ

  Debug:  "FullDuplexSerialPlus"
  Comms:  "FullDuplexSerialPlus"
  PS2:    "PS2_Controller"
  Flt:    "Float32Full"
  FltStr: "FloatString"

VAR
  byte switches0, switches1
  word data [3]
  long hypot, radiX, radiY

PUB Initialize

  Debug.start(31, 30, 0, 57600)
  
  {{Uncomment for TroubleShoot method to work, as of 21FEB10 you can not use
    troubleshoot method while trying to control robot}}
    
  Comms.start(5, 4, 0, 9600)
  PS2.start(0, 1000)
  Flt.start
  Main

PUB Main | idx

  repeat
    data[0] := PS2.get_Data1
    switches0 := data.byte[0]
    switches1 := data.byte[1]
    data.byte[2] := radiX := PS2.get_RightX
    data.byte[3] := radiY := PS2.get_RightY
    data.byte[4] := PS2.get_LeftX
    data.byte[5] := PS2.get_LeftY

    if radiX <= 128
      radiX := 128 - radiX
    else
      radiX := radiX - 128
    Flt.FFloat(radiX)

    if radiY <= 128
      radiY := 128 - radiY
    else
      radiY := radiY - 128
    Flt.FFloat(radiY)

    radiX := Flt.Pow(radiX, SQR)
    radiY := Flt.Pow(radiY, SQR)

    repeat idx from 0 to 6
      if idx == 0
        Comms.str(string("!"))
      else  
        Comms.tx(data.byte[idx-1])
      
    TroubleShoot                      'Uncomment for troubleshooting

PUB TroubleShoot

  Debug.str(string("   RF_Robot Console TroubleShooting   ", Debug#CR))
  Debug.str(string("======================================", Debug#CR))
  Debug.str(string("Switches0 = "))
  Debug.bin(switches0,8)
  Debug.tx(Debug#CLREOL)
  Debug.tx(Debug#CR)
  Debug.str(string("Switches1 = "))
  Debug.bin(switches1,8)
  Debug.tx(Debug#CLREOL)
  Debug.tx(Debug#CR)
  Debug.str(string("rjoystickx = "))
  Debug.dec(data.byte[2])
  Debug.tx(Debug#CLREOL) 
  Debug.tx(Debug#CR)
  Debug.str(string("rjoysticky = "))
  Debug.dec(data.byte[3])
  Debug.tx(Debug#CLREOL) 
  Debug.tx(Debug#CR) 
  Debug.str(string("ljoystickx = "))
  Debug.dec(data.byte[4])
  Debug.tx(Debug#CLREOL) 
  Debug.tx(Debug#CR)
  Debug.str(string("ljoysticky = "))
  Debug.dec(data.byte[5])
  Debug.tx(Debug#CLREOL) 
  Debug.tx(Debug#CR)
  Debug.str(string("Hypotenouse = "))
  Debug.str(FltStr.FloatToString(hypot))
  Debug.tx(Debug#CLREOL)
  Debug.tx(Debug#CR)
  Debug.str(string("X Comonent = "))
  Debug.str(FltStr.FloatToString(radiX))
  Debug.tx(Debug#CLREOL)
  Debug.tx(Debug#CR)
  Debug.str(string("Y Component = "))
  Debug.str(FltStr.FloatToString(radiY))
  Debug.tx(Debug#CLREOL)
  Debug.tx(Debug#CR)
  Debug.str(string("======================================")) 
  Debug.tx(Debug#HOME)   